#
# spec file for package libkgapi
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %define _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           libkgapi
Version:        20.04.2
Release:        lp152.2.3.1
Summary:        Extension for accessing Google data
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM TemporarilyMovedUseSameMethod.patch kde#425261
Patch1:         TemporarilyMovedUseSameMethod.patch
BuildRequires:  cyrus-sasl-devel
BuildRequires:  extra-cmake-modules >= 5.55.0
BuildRequires:  kf5-filesystem
BuildRequires:  cmake(KF5CalendarCore)
BuildRequires:  cmake(KF5Contacts)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Wallet)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(Qt5Core) >= 5.10.0
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network) >= 5.10.0
BuildRequires:  cmake(Qt5Test) >= 5.10.0
BuildRequires:  cmake(Qt5WebEngineWidgets) >= 5.10.0
BuildRequires:  cmake(Qt5Widgets) >= 5.10.0
BuildRequires:  cmake(Qt5Xml) >= 5.10.0
# It can only build on the same platforms as Qt Webengine
ExclusiveArch:  %{ix86} x86_64 %{arm} aarch64 mips mips64
%if %{with lang}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif

%description
An extension for accessing some Google services, such as Google Calendar, Google Contacts and Google tasks.

%package -n libKPimGAPIBlogger5
Summary:        Extension for accessing Google data
Group:          System/GUI/KDE
Recommends:     %{name}-lang = %{version}

%description -n libKPimGAPIBlogger5
An extension for accessing some Google services, such as Google Calendar, Google Contacts and Google tasks.

%package -n libKPimGAPICalendar5
Summary:        Extension for accessing Google data
Group:          System/GUI/KDE
Recommends:     %{name}-lang = %{version}

%description -n libKPimGAPICalendar5
An extension for accessing some Google services, such as Google Calendar, Google Contacts and Google tasks.

%package -n libKPimGAPIContacts5
Summary:        Extension for accessing Google data
Group:          System/GUI/KDE
Recommends:     %{name}-lang = %{version}

%description -n libKPimGAPIContacts5
An extension for accessing some Google services, such as Google Calendar, Google Contacts and Google tasks.

%package -n libKPimGAPICore5
Summary:        Extension for accessing Google data
Group:          System/GUI/KDE
Recommends:     %{name}-lang = %{version}
Provides:       %{name} = %{version}

%description -n libKPimGAPICore5
An extension for accessing some Google services, such as Google Calendar, Google Contacts and Google tasks.

%package -n libKPimGAPIDrive5
Summary:        Extension for accessing Google data
Group:          System/GUI/KDE
Recommends:     %{name}-lang = %{version}

%description -n libKPimGAPIDrive5
An extension for accessing some Google services, such as Google Calendar, Google Contacts and Google tasks.

%package -n libKPimGAPILatitude5
Summary:        Extension for accessing Google data
Group:          System/GUI/KDE
Recommends:     %{name}-lang = %{version}

%description -n libKPimGAPILatitude5
An extension for accessing some Google services, such as Google Calendar, Google Contacts and Google tasks.

%package -n libKPimGAPIMaps5
Summary:        Extension for accessing Google data
Group:          System/GUI/KDE
Recommends:     %{name}-lang = %{version}

%description -n libKPimGAPIMaps5
An extension for accessing some Google services, such as Google Calendar, Google Contacts and Google tasks.

%package -n libKPimGAPITasks5
Summary:        Extension for accessing Google data
Group:          System/GUI/KDE
Recommends:     %{name}-lang = %{version}

%description -n libKPimGAPITasks5
An extension for accessing some Google services, such as Google Calendar, Google Contacts and Google tasks.

%package -n sasl2-kdexoauth2
Summary:        Cyrus SASL plugin for using Google's XOAUTH
Group:          System/GUI/KDE
Conflicts:      kdepim-runtime < %{_kapp_version}
Provides:       sasl2-kdexoauth2-3 = %{version}
Obsoletes:      sasl2-kdexoauth2-3 < %{version}

%description -n sasl2-kdexoauth2
This package provides a Cyrus SASL plugin to use Google's XOAUTH authentication for receiving
and sending mail through Google servers.

%package devel
Summary:        Build environment for libkgapi
Group:          Development/Libraries/KDE
Requires:       libKPimGAPIBlogger5 = %{version}
Requires:       libKPimGAPICalendar5 = %{version}
Requires:       libKPimGAPIContacts5 = %{version}
Requires:       libKPimGAPICore5 = %{version}
Requires:       libKPimGAPIDrive5 = %{version}
Requires:       libKPimGAPILatitude5 = %{version}
Requires:       libKPimGAPIMaps5 = %{version}
Requires:       libKPimGAPITasks5 = %{version}
Requires:       cmake(KF5CalendarCore)
Requires:       cmake(KF5Contacts)
Obsoletes:      libkgapi5-devel < %{version}
Provides:       libkgapi5-devel = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop KDE PIM applications.

%lang_package

%prep
%setup -q -n libkgapi-%{version}
%patch1 -p1

%build
# workaround, kio-gdrive crashes when loading libKPimGAPIDrive5 if built with LTO (boo#1148217)
%define _lto_cflags %{nil}
  %cmake_kf5 -d build -- -DBUILD_TESTING=ON
  %cmake_build

%install
  %kf5_makeinstall -C build
  %if %{with lang}
    %find_lang %{name} --with-man --with-qt --all-name
  %endif

%post -n libKPimGAPIBlogger5 -p /sbin/ldconfig
%postun -n libKPimGAPIBlogger5 -p /sbin/ldconfig
%post -n libKPimGAPICalendar5 -p /sbin/ldconfig
%postun -n libKPimGAPICalendar5 -p /sbin/ldconfig
%post -n libKPimGAPIContacts5 -p /sbin/ldconfig
%postun -n libKPimGAPIContacts5 -p /sbin/ldconfig
%post -n libKPimGAPICore5 -p /sbin/ldconfig
%postun -n libKPimGAPICore5 -p /sbin/ldconfig
%post -n libKPimGAPIDrive5 -p /sbin/ldconfig
%postun -n libKPimGAPIDrive5 -p /sbin/ldconfig
%post -n libKPimGAPILatitude5 -p /sbin/ldconfig
%postun -n libKPimGAPILatitude5 -p /sbin/ldconfig
%post -n libKPimGAPIMaps5 -p /sbin/ldconfig
%postun -n libKPimGAPIMaps5 -p /sbin/ldconfig
%post -n libKPimGAPITasks5 -p /sbin/ldconfig
%postun -n libKPimGAPITasks5 -p /sbin/ldconfig

%files -n libKPimGAPIBlogger5
%license LICENSE
%{_kf5_libdir}/libKPimGAPIBlogger.so.*

%files -n libKPimGAPICalendar5
%license LICENSE
%{_kf5_libdir}/libKPimGAPICalendar.so.*

%files -n libKPimGAPIContacts5
%license LICENSE
%{_kf5_libdir}/libKPimGAPIContacts.so.*

%files -n libKPimGAPICore5
%license LICENSE
%{_kf5_libdir}/libKPimGAPICore.so.*
%{_kf5_debugdir}/libkgapi.categories

%files -n libKPimGAPIDrive5
%license LICENSE
%{_kf5_libdir}/libKPimGAPIDrive.so.*

%files -n libKPimGAPILatitude5
%license LICENSE
%{_kf5_libdir}/libKPimGAPILatitude.so.*

%files -n libKPimGAPIMaps5
%license LICENSE
%{_kf5_libdir}/libKPimGAPIMaps.so.*

%files -n libKPimGAPITasks5
%license LICENSE
%{_kf5_libdir}/libKPimGAPITasks.so.*

%files -n sasl2-kdexoauth2
%license LICENSE
%dir %{_kf5_libdir}/sasl2/
%{_kf5_libdir}/sasl2/libkdexoauth2.so*

%files devel
%license LICENSE
%{_includedir}/KPim/
%{_kf5_cmakedir}/KPimGAPI/
%{_kf5_libdir}/libKPimGAPIBlogger.so
%{_kf5_libdir}/libKPimGAPICalendar.so
%{_kf5_libdir}/libKPimGAPIContacts.so
%{_kf5_libdir}/libKPimGAPICore.so
%{_kf5_libdir}/libKPimGAPIDrive.so
%{_kf5_libdir}/libKPimGAPILatitude.so
%{_kf5_libdir}/libKPimGAPIMaps.so
%{_kf5_libdir}/libKPimGAPITasks.so
%{_kf5_mkspecsdir}/qt_KGAPIBlogger.pri
%{_kf5_mkspecsdir}/qt_KGAPICalendar.pri
%{_kf5_mkspecsdir}/qt_KGAPIContacts.pri
%{_kf5_mkspecsdir}/qt_KGAPICore.pri
%{_kf5_mkspecsdir}/qt_KGAPIDrive.pri
%{_kf5_mkspecsdir}/qt_KGAPILatitude.pri
%{_kf5_mkspecsdir}/qt_KGAPIMaps.pri
%{_kf5_mkspecsdir}/qt_KGAPITasks.pri

%if %{with lang}
%files lang -f %{name}.lang
%license LICENSE
%endif

%changelog
* Fri Oct 30 2020 opensuse.lietuviu.kalba@gmail.com
- Add TemporarilyMovedUseSameMethod.patch to fix kde#425261
  to accept HTTP status 307 as a redirect; otherwise Google document
  download fails with an unknown error.
  This upstream patch backported from libkgapi 20.08.2.
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- No code change since 20.04.0
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- No code change since 20.03.90
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- No code change since 20.03.80
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Changes since 19.12.3:
  * Undo switch to networkError() getter
  * It was reverted in qt5.15
  * Make it compile against qt5.15
  * Fix clazy warning
  * Make it compile against last qt5.15 without deprecated methods
  * Port to QComboBox
  * Fix typos, update links
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Changes since 19.12.2:
  * Fix typo in event status
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- Changes since 19.12.1:
  * Handle 410 Gone errors during Calendar sync
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- No code change since 19.12.0
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Make it compile with last qt5.14
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- No code change since 19.11.80
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Changes since 19.08.3:
  * Fix minor typo
  * Fix comparison typo
  * Cleanup and modernize the Calendar library codebase
  * Add missing parameters to Permission related jobs and fix url typo.
  * QString::remove operates on the same object, no need to reassign
  * Use QLatin1String overload for QString::operator ==/!=
  * Use QLatin1String in join/startswith/endsWith/contains + QString::replace
    operates on the same object, no need to reassign
  * Fix API docs generation
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- No code change since 19.08.2
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- Changes since 19.08.1:
  * Fix null pointer dereference, keep FileModifyJob metadata and serialize with options. (kde#411634)
  * Fix compilation with Qt 5.14
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- Changes since 19.08.0:
  * Include KDE* cmake macros before any others
* Tue Aug 27 2019 wbauer@tmo.at
- Temporarily disable LTO to avoid crash when using gdrive
  (boo#1148217)
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * Adapt to KCalendarCore namespace change
  * Use mimeType from metadata instead of blindly re-determining it during uploads
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
* Thu Jul 18 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use kf5_debugdir macro for specifying the logging categories location
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- No code changes since 19.04.2
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- No code changes since 19.04.0
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Workaround qt5.13 bug
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * Fix googletalk protocol.
  * Contacts: fix email type deserialization (kde#398847)
- Dropped patches, now upstream:
  * Contacts-fix-email-type-deserialization.patch
* Mon Feb 25 2019 wbauer@tmo.at
- Add Contacts-fix-email-type-deserialization.patch to fix broken
  email fields in google contacts (boo#1126614, kde#398847)
- Use < %%{version} again for obsoleting sasl2-kdexoauth2-3
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * No code changes since 18.12.0
* Sat Dec 15 2018 Jan Engelhardt <jengelh@inai.de>
- Generalize summaries.
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * QT_NO_NARROWING_CONVERSIONS_IN_CONNECT is defined in kf5.51
  * Fix minor EBN issues
  * Relicense the XOAuth SASL plugin under LGPLv2.1+
  * Make sure that it doesn't build with deprecated method
  * Add more flags
  * Fix warning
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * No code changes since 18.08.2
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * Fix compilation with Qt 5.12
* Thu Oct  4 2018 fabian@ritter-vogt.de
- We actually need <= as the version did not get bumped
* Wed Sep 19 2018 Luca Beltrame <lbeltrame@kde.org>
- Use < instead of <= when obsoleting sasl2-kdexoauth2-3 to prevent
  self-obsoletion
* Mon Sep 17 2018 Wolfgang Bauer <wbauer@tmo.at>
- Rename sasl2-kdexoauth2-3 to sasl2-kdexoauth2, it is not a shared
  library but a plugin for sasl2, and it makes no sense to have
  several versions installed at the same time
- Provide sasl2-kdexoauth2-3 for now to avoid dependency problems
  and to replace the old package
- Move libkdexoauth2.so from libkgapi-devel to sasl2-kdexoauth2,
  apparently it's required on runtime for gmail/xoauth
  authentification to work (boo#1108577, kde#375410)
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * gmail auth: return proper HTTP response to avoid qwebengine error
  * Fix typos
* Sat Sep  1 2018 fabian@ritter-vogt.de
- Remove unnecessary WebKitWidgets dependency
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Fix build against Qt < 5.10
  * Replace KGAPIRaw logging category with file logging
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Too many changes to list here
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * None
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * None
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * None
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Remove extra ';'
  * Use override directly
  * USe QLatin1String
  * Set error if oauth dialog is aborted
  * Fix minor typos
  * Make new user-visible messages translatable
  * Fix token page URL (kde#388483)
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * None
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Fix oauth focus (kde#389263)
  * Reenable setting the authentication URL
  * Retrieve OAuth2 token with HTTP socket
  * Check for the correct "kind" strings
  * Fix token page URL (kde#388483)
- Dropped patches, now upstream:
  * Fix-token-page-URL.patch
* Sat Jan 13 2018 wbauer@tmo.at
- Add Fix-token-page-URL.patch to make authentification with
  Google services work again after a change by Google (kde#388483)
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * None
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * Contacts: fix sync of alternative URL types (kde#387344)
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * None
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Port to new connect api
  * Port to new connect api
  * Port to new connect api
  * Remove project here
  * not necessary to have project here
  * Fix merge conflict
  * Add parent
  * Fix includes
  * Adapt to KCalCore API changes
  * Port Period and Duration to QDateTime
  * Adapt to KCalCore lastModified/created API changes
  * We can remove this compatibility now
  * Make run without install them
  * Remove unused line
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * lintcmake https://build.neon.kde.org/job/xenial_stable_applications_libkgapi_lintcmake/21/console Unknown CMake command "find_dependency".
  * Fix version
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * None
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * Update version
  * Revert "Try to fix build on windows"
  * Try to fix build on windows
  * Fix compile on windows
  * Use isEmpty() here
  * Add more definitions QT_NO_URL_CAST_FROM_STRING
  * Remove Qt module from include
  * Remove module name
  * Use nullptr
  * use nullptr
  * Pedantic
  * Use qCDebug
  * Fix indent
  * Port to for(...:...)
  * Port some others Q_FOREACH
  * Remove more q_foreach
  * Convert some Q_FOREACH
  * not necessary
  * Port to for(...:...)
  * We depend against qt5.7
  * Increase version
  * Fix dependancies
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sun Jul 16 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Prepare 5.5.1
  * Auth: add URL bar and SSL indicator to the authentication page
  * Auth: don't store cookies
  * Auth: Adapt to changes in Google OAuth token retrieval process
  * Use same variable as other lib. It's more easy to upgrade version
  * Fix some clazy warning
- Drop upstreamed patches:
  * adapt-to-changes-in-google-oauth.patch
* Thu Apr 27 2017 lbeltrame@kde.org
- Add upstream patch adapt-to-changes-in-google-oauth.patch:
  * Fix for changes in Google OAuth process
* Fri Apr 21 2017 lbeltrame@kde.org
- Remove all Recommends on non-core packages, since they will
  require the core one
* Fri Apr 21 2017 lbeltrame@kde.org
- Make libKPimGAPICore5 provide libkgapi, so that instaling
  languages (which use a single file) will work
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * Fix some clazy warning
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Fri Mar 31 2017 fabian@ritter-vogt.de
- Build only for architectures compatible with Qt WebEngine
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 5.3.1:
  * increase dependancies
  * Use KDE_INSTALL_TARGETS_DEFAULT_ARGS when installing targets
  * It's in official release + we don't use i18n
  * Fixup .reviewboardrc
  * src/latitude/latitudeservice.cpp - Q_UNUSED
  * Make Qt l10 tools happier
  * Fix version
  * AuthJob: emit finished() when dialog is rejected
  * Rename CMake target prefix from KF5 to KPim
  * Fix typo in quotaBytesUserAggregate() method
  * Fix compile with Qt 5.8: add missing QImage includes
  * Fix compile with Qt 5.8: add missing QImage includes
  * USe nullptr
  * Add missing Q_DECL_OVERRIDE
  * Clean up. Increase qt dependancy
  * use Q_NULLPTR
  * Increase version
  * increase version
  * drive: deprecate hidden() and setHidden() in File
  * Relicense to LGPLv2.1 or v3 or later versions approved by KDE e.V.
  * Remove stray WebKitWidgets reference.
  * Remove unused KF5CoreAddons dependency.
  * Switch to QtWebEngine
  * Move tests to autotests
  * Update AUTHORS
  * Increase version
  * Fix ts2Str() UTC conversion
* Fri Sep 30 2016 fabian@ritter-vogt.de
- Update to 5.3.1
  * No changelog provided
* Sun Aug 21 2016 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * No changelog provided
* Sun Jan 17 2016 tittiatcoke@gmail.com
- Update to 5.1.0
  * KDE Frameworks 5 based version. (boo#953617)
* Sat Aug 16 2014 tittiatcoke@gmail.com
- Update to 2.2.0
  * Final release
* Fri Jul 11 2014 cgiboudeaux@gmx.com
- Update to 2.1.80
  * Added Blogger API
* Tue Apr 29 2014 hrvoje.senjan@gmail.com
- Update to 2.1.1
  * Bugfix release, no changelog provided
* Tue Mar 11 2014 hrvoje.senjan@gmail.com
- Update to 2.1.0
  * Added support for Google Drive API v2
- Dropped 0001-When-fetching-last-contact-photo-fails-don-t-fail-th.patch,
  merged upstream
- Drop libkgapi1, libkgapi1-devel and libkgapi2-devel packages, per
  upstream changes
* Fri Dec  6 2013 hrvoje.senjan@gmail.com
- Update to 2.0.2
  * Add support for Microsoft Standard Time Zones
  * Respect calendar-wide timezones
- Added 0001-When-fetching-last-contact-photo-fails-don-t-fail-th.patch,
  for resolving kde#328422, where the synchronization of google resource
  could fail of contact wouldn't have a photo
* Fri Jun 14 2013 hrvoje.senjan@gmail.com
- Add missing %%files section for devel package
* Sat Jun  1 2013 hrvoje.senjan@gmail.com
- Update to 2.0.1
  * Fixed new account authentication with legacy API
* Fri May 24 2013 hrvoje.senjan@gmail.com
- Update to 2.0.0
  * new LibKGAPI 2 API, breaks ABI, old API is preserved
  * new job-based API that deprecates the old one. It is cleaner,
    more flexible and much easier to use
- Obsolete libkgapi0
- Add new libkgapi-devel package which depends on both libkgapi1-devel
  and libkgapi2-devel, until we can depend purely on libkgapi2-devel
- Drop usage of fdupes
* Wed Dec 19 2012 nico.kruber@gmail.com
- Update to 0.4.4
  * fixed kde#309314 - Contacts with XML-unsafe characters not stored
  * fixed kde#309318 - Support custom IM protocols
  * fixed kde#310177 - Support birthday dates without year specified
  * fixed kde#310851 - Handle Microsoft TZIDs
* Tue Oct 23 2012 cgiboudeaux@gmx.com
- Update to 0.4.3
  * Fix kde#307719 - Don't duplicate instances detached from a recurrent event
  * Fix kde#308462 - Don't emit authentication success when it actually fails
  * fixed a typo in calendar parser that caused all calendars to have read-only flag
* Wed Oct 10 2012 nico.kruber@gmail.com
- remove self-obsoletes
- also obsolete akonadi-google
  (changes come from KR49, mainly attributed to toddrme2178@gmail.com)
* Tue Sep 11 2012 cgiboudeaux@gmx.com
- Add libkgapi. A Library to access some Google data.
  It is a build requirement for kdepim-runtime > 4.9
